@@ -1067,6 +1067,7 @@ class WorkflowBase(Base):
 
             work.initialize_work()
             work.sync_global_parameters(self.global_parameters)
+            work.renew_parameters_from_attributes()
             work.num_run = self.num_run
             works = self.works
             self.works = works
@@ -1078,6 +1079,19 @@ class WorkflowBase(Base):
 
         return work
 
+    def get_new_parameters_for_work(self, work):
+        new_parameters = self.get_destination_parameters(work.get_internal_id())
+        if new_parameters:
+            work.set_parameters(new_parameters)
+        work.sequence_id = self.num_total_works
+
+        work.initialize_work()
+        work.sync_global_parameters(self.global_parameters)
+        work.renew_parameters_from_attributes()
+        works = self.works
+        self.works = works
+        return work
+
     def register_user_defined_condition(self, condition):
         cond_src = inspect.getsource(condition)
         self.user_defined_conditions[condition.__name__] = cond_src
@@ -1283,6 +1297,7 @@ class WorkflowBase(Base):
         works = []
         for k in self.new_to_run_works:
             if isinstance(self.works[k], Work):
+                self.works[k] = self.get_new_parameters_for_work(self.works[k])
                 works.append(self.works[k])
             if isinstance(self.works[k], Workflow):
                 works = works + self.works[k].get_new_works()
@@ -1328,14 +1343,26 @@ class WorkflowBase(Base):
         """
 
         if self.primary_initial_work:
-            return self.get_works()[self.primary_initial_work].get_primary_input_collection()
+            if isinstance(self.get_works()[self.primary_initial_work], Workflow):
+                return self.get_works()[self.primary_initial_work].get_primary_initial_collection()
+            else:
+                return self.get_works()[self.primary_initial_work].get_primary_input_collection()
         elif self.initial_works:
-            return self.get_works()[self.initial_works[0]].get_primary_input_collection()
+            if isinstance(self.get_works()[self.initial_works[0]], Workflow):
+                return self.get_works()[self.initial_works[0]].get_primary_initial_collection()
+            else:
+                return self.get_works()[self.initial_works[0]].get_primary_input_collection()
         elif self.independent_works:
-            return self.get_works()[self.independent_works[0]].get_primary_input_collection()
+            if isinstance(self.get_works()[self.independent_works[0]], Workflow):
+                return self.get_works()[self.independent_works[0]].get_primary_initial_collection()
+            else:
+                return self.get_works()[self.independent_works[0]].get_primary_input_collection()
         else:
             keys = self.get_works().keys()
-            return self.get_works()[keys[0]].get_primary_input_collection()
+            if isinstance(self.get_works()[keys[0]], Workflow):
+                return self.get_works()[keys[0]].get_primary_initial_collection()
+            else:
+                return self.get_works()[keys[0]].get_primary_input_collection()
         return None
 
     def get_dependency_works(self, work_id, depth, max_depth):
